@@ -140,10 +140,11 @@ class SkeletonVisualizer:
                                automatic_camera_orientation: bool = False) -> None:
         self.__init_skeleton_plot(skeletons, automatic_camera_orientation)
         skeleton_part_size: float = self.__calculate_skeleton_part_size(skeletons)
+        print(positions)
         if positions is None:
             positions = skeletons
-        skeletons: List[Skeleton] = self.__get_skeletons(positions, colors, skeleton_part_size)
-        drawable_skeletons: List[DrawableSkeleton] = [skeleton_converter(skeleton) for skeleton in skeletons]
+        skeleton_objects: List[Skeleton] = self.__get_skeletons(positions, colors, skeleton_part_size)
+        drawable_skeletons: List[DrawableSkeleton] = [skeleton_converter(skeleton) for skeleton in skeleton_objects]
         self.__add_skeletons_to_plot(drawable_skeletons)
 
     def __init_skeleton_plot(self, skeletons: np.ndarray, automatic_camera_orientation: bool = False) -> None:
@@ -169,9 +170,8 @@ class SkeletonVisualizer:
 
     def __get_skeletons(self, positions: List[Positions], colors: List[Color],
                         skeleton_part_size: float, is_gt_list: List[bool] = None) -> List[Skeleton]:
-        length: int = len(positions)
         if is_gt_list is None:
-            is_gt_list = [False] * length
+            is_gt_list = [False] * len(colors)
         return list(map(lambda parameter_tuple: Skeleton(
             joint_positions=parameter_tuple[0],
             joint_set=self.joint_set,
